@@ -14,10 +14,10 @@ class WebPageError(Exception):
 
 class TestWebPage(unittest.TestCase):
     def setUp(self):
-        self.mypage = WebPage("./test.html","w",bgcolour="powderblue")
+        self.mypage = WebPage("test.html","w",bgcolour="powderblue")
     
     def test_init(self):
-        self.assertEqual(self.mypage.file,"./test.html")
+        self.assertEqual(self.mypage.file,"test.html")
         self.assertEqual(self.mypage.action, "w")
         self.assertEqual(self.mypage.tabhead, "HTML with Python!")
         self.assertEqual(self.mypage.bgcolour, "background-color:powderblue")
@@ -36,5 +36,6 @@ def cleanup():
     os.remove("./test.html")
     if os.path.exists("./alien_hurt.ico"):
         os.remove("./alien_hurt.ico")
-    
-unittest.main()
\ No newline at end of file
+
+def run():
+    unittest.main()
\ No newline at end of file
